@@ -1,8 +1,9 @@
 package Koha::Contrib::Tamil::Koha;
 #ABSTRACT: Class exposing info about a Koha instance.
-$Koha::Contrib::Tamil::Koha::VERSION = '0.052';
+$Koha::Contrib::Tamil::Koha::VERSION = '0.053';
 use Moose;
 
+use Modern::Perl;
 use Carp;
 use XML::Simple;
 use DBI;
@@ -10,6 +11,7 @@ use ZOOM;
 use MARC::Record;
 use MARC::File::XML;
 use YAML;
+use C4::Biblio;
 
 
 
@@ -27,6 +29,9 @@ has conf => ( is => 'rw' );
 has _zconn => ( is => 'rw', isa => 'HashRef' );
 
 
+has _old_marc_biblio_sub => ( is => 'rw', isa => 'Bool', default => 0 );
+
+
 sub BUILD {
     my $self = shift;
 
@@ -57,6 +62,13 @@ sub BUILD {
 
     # Zebra connections 
     $self->_zconn( { biblio => undef, auth => undef } );
+
+    my $version = C4::Context->preference('Version');
+    if ( $version =~ /^([0-9]{2})\.([0-9]{2})/ ) {
+        $version = "$1.$2";
+        $version += 0;
+        $self->_old_marc_biblio_sub(1) if $version <= 17.05;
+    }
 }
 
 
@@ -152,6 +164,18 @@ s/[^\x09\x0A\x0D\x{0020}-\x{D7FF}\x{E000}-\x{FFFD}\x{10000}-\x{10FFFF}]//g;
 }
 
 
+
+sub get_biblio {
+    my ( $self, $id ) = @_; 
+
+    my $record = $self->_old_marc_biblio_sub
+        ? GetMarcBiblio($id)
+        : GetMarcBiblio({biblionumber => $id});
+    return unless $record;
+    return MARC::Moose::Record::new_from($record, 'Legacy');
+}
+
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -168,7 +192,7 @@ Koha::Contrib::Tamil::Koha - Class exposing info about a Koha instance.
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 ATTRIBUTES
 
@@ -210,13 +234,17 @@ Returns a L<ZOOM::connection> to Koha authority records Zebra server.
 
 Return a MARC::Record from its biblionumber
 
+=head2 get_biblio($biblionumber)
+
+Return a MARC::Moose::Record from its biblionumber. It's a wrapper around GetMarcBiblio()
+
 =head1 AUTHOR
 
 Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Fréderic Démians.
+This software is Copyright (c) 2018 by Fréderic Démians.
 
 This is free software, licensed under:
 
